/***************************************************************************
                          setpagegeneral.h  -  description
                             -------------------
    begin                : Fri Nov 23 2001
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SETPAGEGENERAL_H
#define SETPAGEGENERAL_H

#include <klineedit.h>
#include <tqwidget.h>
#include <tqhbox.h>
#include <tqlabel.h>
#include <tqlayout.h>
#include <tqgroupbox.h>
#include <tqbuttongroup.h>
#include <tqpushbutton.h>
#include <tqradiobutton.h>
#include <tqcheckbox.h>
#include "resource.h"

/**
  *@author Troy Corbin Jr.
  */

class setPageGeneral : public TQVBoxLayout
{
		TQ_OBJECT
  
	public:
										setPageGeneral(TQWidget *parent=0, resource *Rsrc=0);
										~setPageGeneral();
	signals:
		void						enableApply( void );
	public slots:
		void						slot_AutoSave( int state );
		void						slot_Init( int state );
		void						slot_UserName( const TQString& );
		void						slot_Pause_On_Minimize( bool state );
		void						slot_Auto_Queen( bool state );
		void						slot_Auto_Flag( bool state );
		void						slot_Delete_Logs( bool state );
		void						slot_Reuse_PGN( bool );
		void						slot_PGN_Filename( const TQString& );
		void						slot_PGN_Filename_Button( void );
	private:
		TQWidget 				*Parent;
		resource				*Resource;

		TQGroupBox							*GROUP_UserName;
			KLineEdit							*EDIT_UserName;
		TQHBox									*BOX_SaveInit;
			TQButtonGroup					*GROUP_AutoSave;
				TQRadioButton					*BUTTON_AutoSave_Yes;
				TQRadioButton					*BUTTON_AutoSave_No;
				TQRadioButton					*BUTTON_AutoSave_Ask;
			TQButtonGroup					*GROUP_OnInit;
				TQRadioButton					*BUTTON_Init_Nothing;
				TQRadioButton					*BUTTON_Init_VsPC;
				TQRadioButton					*BUTTON_Init_Connect;
		TQGroupBox							*GROUP_Reuse_PGN;
			TQCheckBox							*BUTTON_Reuse_PGN;
			TQHBox									*BOX_Reuse_PGN;
				KLineEdit							*EDIT_PGN_Filename;
				TQPushButton					*BUTTON_PGN_Filename;
		TQCheckBox							*BUTTON_Pause_On_Minimize;
		TQCheckBox							*BUTTON_Auto_Queen;
		TQCheckBox							*BUTTON_Auto_Flag;
		TQCheckBox							*BUTTON_Delete_Logs;
};

#endif
